@@ -40,14 +40,14 @@
 
 static gint setupdialog_destroy(GtkWidget *widget, gint mode);
 static GtkWidget *setupdialog = NULL;
-static GtkWidget *HumanSpinner, *ComputerSpinner, *BonusEntry;
+static GtkWidget *HumanSpinner, *ComputerSpinner;
 static GtkWidget *PlayerNames[MAX_NUMBER_OF_PLAYERS];
 static GtkObject *HumanAdj, *ComputerAdj;
 
 static int OriginalNumberOfComputers = -1;
 static int OriginalNumberOfHumans    = -1;
 
-static int tmpExtraYahtzeeBonus, tmpExtraYahtzeeJoker, tmpDoDelay, tmpDisplayComputerThoughts;
+static int tmpDoDelay, tmpDisplayComputerThoughts;
 
 extern GtkWidget *window;
 
@@ -98,7 +98,6 @@ WarnNumPlayersChanged (void)
                                      _("Current game will complete" 
                                        " with original number of players."));
         gtk_window_set_position (GTK_WINDOW (mb), GTK_WIN_POS_MOUSE);
-        gtk_dialog_set_has_separator (GTK_DIALOG (mb), FALSE);
         gtk_dialog_run (GTK_DIALOG (mb));
         gtk_widget_destroy (mb);
 }
@@ -119,8 +118,6 @@ do_setup (GtkWidget *widget, gpointer data)
 
         DoDelay = tmpDoDelay;
         DisplayComputerThoughts = tmpDisplayComputerThoughts;
-        ExtraYahtzeeBonus = tmpExtraYahtzeeBonus;
-        ExtraYahtzeeJoker = tmpExtraYahtzeeJoker;
 
         for (i=0; i < MAX_NUMBER_OF_PLAYERS; i++) {
                 if (players[i].name != DefaultPlayerNames[i])
@@ -132,10 +129,6 @@ do_setup (GtkWidget *widget, gpointer data)
                                                      players[i].name);
                 name_list = g_slist_append (name_list, players[i].name);
         }
-
-        if (sscanf (gtk_entry_get_text (GTK_ENTRY (BonusEntry)),"%d",&i)==1) {
-                ExtraYahtzeeBonusVal = i;
-        } 
                 
 	setupdialog_destroy (setupdialog, 1);
 
@@ -165,30 +158,14 @@ do_setup (GtkWidget *widget, gpointer data)
                 err = NULL;
         }
 
-        gconf_client_set_int (client, "/apps/gtali/ExtraYahtzeeBonus",
-                              ExtraYahtzeeBonus, &err);
+        gconf_client_set_bool (client, "/apps/gtali/DelayBetweenRolls",
+                              DoDelay, &err);
         if (err) {
                 g_warning (G_STRLOC ": gconf error: %s\n", err->message);
                 g_error_free (err);
                 err = NULL;
         }
-
-        gconf_client_set_int (client, "/apps/gtali/ExtraYahtzeeBonusVal",
-                              ExtraYahtzeeBonusVal, &err);
-        if (err) {
-                g_warning (G_STRLOC ": gconf error: %s\n", err->message);
-                g_error_free (err);
-                err = NULL;
-        }
-
- 	gconf_client_set_int (client, "/apps/gtali/ExtraYahtzeeJoker",
-                              ExtraYahtzeeJoker, &err);
-        if (err) {
-                g_warning (G_STRLOC ": gconf error: %s\n", err->message);
-                g_error_free (err);
-                err = NULL;
-        }
-
+        
         if ( ( (NumberOfComputers != OriginalNumberOfComputers)
                || (NumberOfHumans != OriginalNumberOfHumans) )
              && !GameIsOver () )
@@ -211,10 +188,7 @@ static gint
 set_as_int (GtkWidget *widget, gpointer *data)
 {
         *((int *)data) = GTK_TOGGLE_BUTTON (widget)->active;
-        if (data == (gpointer)&tmpExtraYahtzeeBonus) {
-                gtk_editable_set_editable (GTK_EDITABLE (BonusEntry),
-                                           GTK_TOGGLE_BUTTON (widget)->active);
-        }
+
         return FALSE;
 }
 
@@ -297,18 +271,6 @@ setup_game (GtkWidget *widget, gpointer data)
 	HumanSpinner = gtk_spin_button_new (GTK_ADJUSTMENT (HumanAdj), 10, 0);
         gtk_size_group_add_widget (group2, HumanSpinner);
 
-#if 0
-#ifndef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
-        gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (HumanSpinner),
-                                           GTK_UPDATE_ALWAYS 
-                                           | GTK_UPDATE_SNAP_TO_TICKS);
-#else
-        gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (HumanSpinner),
-                                           GTK_UPDATE_ALWAYS );
-	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (HumanSpinner),
-                                           TRUE);
-#endif
-#endif
         g_signal_connect (G_OBJECT (HumanAdj), "value_changed",
                           G_CALLBACK (MaxPlayersCheck), HumanAdj);
  
@@ -329,15 +291,6 @@ setup_game (GtkWidget *widget, gpointer data)
         g_signal_connect (G_OBJECT (button), "clicked",
                           G_CALLBACK (set_as_int), &tmpDoDelay);
 
-        /*--- Button ---*/
-	button = gtk_check_button_new_with_label (_("Show thoughts during turn") );
-	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-                                      DisplayComputerThoughts);
-        g_signal_connect (G_OBJECT (button), "clicked",
-                          G_CALLBACK (set_as_int),
-                          &tmpDisplayComputerThoughts);
-
         /*--- Spinner (number of computers) ---*/
         OriginalNumberOfComputers = NumberOfComputers;
 	box2 = gtk_hbox_new (FALSE, 12);
@@ -352,68 +305,10 @@ setup_game (GtkWidget *widget, gpointer data)
                                                10, 0);
         gtk_size_group_add_widget (group2, ComputerSpinner);
 
-#if 0
-#ifndef HAVE_GTK_SPIN_BUTTON_SET_SNAP_TO_TICKS
-        gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (ComputerSpinner),
-                                           GTK_UPDATE_ALWAYS 
-                                           | GTK_UPDATE_SNAP_TO_TICKS);
-#else
-        gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (ComputerSpinner),
-                                           GTK_UPDATE_ALWAYS );
-	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (ComputerSpinner),
-                                           TRUE);
-#endif
-#endif
         g_signal_connect (G_OBJECT (ComputerAdj), "value_changed",
                           G_CALLBACK (MaxPlayersCheck), ComputerAdj);
         gtk_box_pack_start (GTK_BOX (box2), ComputerSpinner, FALSE, TRUE, 0);
 
-
-        /*--- OPTIONAL RULES FRAME ----*/
- 	frame = games_frame_new (_("Optional Rules"));
-        gtk_table_attach_defaults (GTK_TABLE (table), frame, 0, 1, 2, 3);
- 	
- 	box = gtk_vbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (box), 8);
- 	gtk_container_add (GTK_CONTAINER (frame), box);
- 
-        /*--- Button ---*/
- 	box2 = gtk_hbox_new (FALSE, 12);
- 	gtk_box_pack_start (GTK_BOX (box), box2, TRUE, TRUE, 0);
- 
- 	button = gtk_check_button_new_with_label (_("Extra Yahtzee Bonus") );
- 	/*gtk_box_pack_start (GTK_BOX (box2), button, FALSE, FALSE, 0);*/
- 	gtk_box_pack_start (GTK_BOX (box2), button, TRUE, TRUE, 0);
-        gtk_size_group_add_widget (group1, button);
-        tmpExtraYahtzeeBonus = ExtraYahtzeeBonus;
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-                                      ExtraYahtzeeBonus);
-        g_signal_connect (G_OBJECT (button), "clicked",
-                          G_CALLBACK (set_as_int), &tmpExtraYahtzeeBonus);
-
-        BonusEntry = gtk_entry_new ();
-        gtk_size_group_add_widget (group2, BonusEntry);
-        gtk_entry_set_max_length (GTK_ENTRY (BonusEntry),3);
-        /* Why is it so damn big by default? */
-        gtk_widget_set_size_request (BonusEntry, 50, -1);
-        ts = g_strdup_printf ("%3d", ExtraYahtzeeBonusVal);
-        gtk_entry_set_text (GTK_ENTRY (BonusEntry),ts);
-        g_free (ts);
-        if (! ExtraYahtzeeBonus) {
-                gtk_editable_set_editable (GTK_EDITABLE (BonusEntry), FALSE);
-        }
-        gtk_box_pack_start (GTK_BOX (box2), BonusEntry, TRUE, TRUE, 0);
-        
-        /*--- Button ---*/
- 	button = gtk_check_button_new_with_label (_("Enforce Joker Rules"));
-        tmpExtraYahtzeeJoker = ExtraYahtzeeJoker;
- 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
-                                      ExtraYahtzeeJoker);
-        g_signal_connect (G_OBJECT (button), "clicked",
-                          G_CALLBACK (set_as_int), &tmpExtraYahtzeeJoker);
-        gtk_widget_set_sensitive (button, FALSE); /* NOT READY YET */
-        
         /*--- PLAYER NAMES FRAME ----*/
 	frame = games_frame_new (_("Player Names"));
         gtk_table_attach_defaults (GTK_TABLE (table), frame, 1, 2, 0, 3);
